# APACHE Module

## Overview

This module install and configure apache web server.

## Usage

Default configuration:

```puppet
include apache
```

Change configuration file settings:

```puppet
class { 'apache':
    servername            => 'www.example.com',
    listen                => [ '80' ],
    include               => [ 'sites-enabled/*.conf' ],
    serversignature       => 'Off',
    servertokens          => 'Prod',
    fileetag              => 'None',
    timeout               => '60',
    keepalivetimeout      => '15',
    limitrequestfields    => '100',
    limitrequestfieldsize => '8190',
    namevirtualhost       => [ '*.80' ],
    user                  => 'apache',
    group                 => 'apache',
}
```

Create virtualhost:

```puppet
apache::virtualhost { 'example.com.conf':
    filename        => 'example.com.conf',
    virtualhost     => {
        '*:80' => [
            'ServerAdmin admin@example.com',
            'DocumentRoot /var/www/example.com/public_html/',
            'ServerName example.com',
            'ServerAlias www.example.com',
            'ErrorLog logs/example.com-error.log',
            'CustomLog logs/example.com-access.log combined',
        ],
    },
}
```

Proxy customisation:

```puppet
class { 'apache':
    proxyrequests   => 'Off',
    proxypass       => '/ balancer://cluster lbmethod=byrequests',
    proxy           => {
        '*' => [
            'Order deny,allow',
            'Deny from none',
            'Allow from all',
        ],
        'balancer://cluster' => [
            'BalancerMember http://node1.example.com/ loadfactor=1',
            'BalancerMember http://node2.example.com/ loadfactor=1',
        ],
    },
}
```

Modsecurity customisation:

```puppet
class { 'apache::modsecurity':
    secruleengine           => 'On',
    secrequestbodyaccess    => 'On',
    secresponsebodyaccess   => 'On',
    secdatadir              => undef,
}
```

Modevasive customisation:

```puppet
class { 'apache::modevasive':
    dosemailnotify         => 'admin@example.com',
    dospagecount           => '2',
    dossitecount           => '50',
    dosblockingperiod      => '10',
    doslogdir              => '/var/log/mod_evasive',
    doswhitelist           => [ '127.0.0.1', '192.168.0.*' ],
}
```

